%This program calls the FastICA, Infomax, JADE, Radical and Beta-Divergene contrast functions
function Cntrst_ICA = CCECE05_Exp1_Cntrst_Caller(x,A,whiteningMatrix_x)

%Neil Gadhok, v1.0, Mar 6, 2005.
%NOTE: ASSUME x has been whitened.

[m,n] = size(x);
Betas = [0,0.05,0.1,0.2,0.3];
Gf = [1,2,3,4]; %The nonlinearities for FastICA

   %For FastICA, easier than calculating the exact expectation in Eqn 8.25
   % IF the mean of G(v) changes, the landscape changes drastically!!!!
   %Create v, a Gaussian variable of zero mean on unit variance.
    v = randn(1,n);
    v = v - mean(v,2)*ones(1,length(v)); %Make v zero mean
    [E, D] = eig (cov(v', 1)); %The 1 normalizes by N.
    whiteningMatrix_v = inv (sqrt (D)) * E';
    v = whiteningMatrix_v*v;

%Determine the landscapes
   N = 50;  %Number of angles to search
   mN= floor(sqrt(n));
   theta = linspace(0,pi/2,N);
    
%Calculate the Likelihood for different W rotation matrices
%Note: The contrast have been modified such that we are looking to minimize each one.
    Cntrst_FastICA = zeros(length(Gf),N);
    Cntrst_Infomax = zeros(1,N);
    Cntrst_JADE = zeros(1,N);
    Cntrst_Radical = zeros(1,N);
    Cntrst_BetaD = zeros(length(Betas),N);
    
      
    disp('Calculating Contrasts....');
    for index = 1:N,
       
        W	=  [ cos(theta(index)) -sin(theta(index)) ; sin(theta(index)) cos(theta(index)) ] ; %Rotation matrix 
        API = Amari(W*whiteningMatrix_x*A); %The same for each contrast function
                
        %FastICA
        %disp('FastICA Contrast....');
        for G = 1:length(Gf), %For each nonlinearity {1}, %G1 = (1/a1)*log(cosh(a1*y)); %G2 = - exp(-(y.^2))./2); %G3 = (y^4)/4; %G4 = {y.^3);
            Cntrst_FastICA(G,index) = FastICA_Cntrst(x,W,v,G);
        end
        API_FastICA(index) = API; 
        
        
        %Infomax
        %disp('Infomax Contrast....');
        Cntrst_Infomax(index) = Infomax_Cntrst(x,W);
        API_Infomax(index) = API; 
     
        %JADE
        %disp('JADE Contrast....');
        Cntrst_JADE(index) = JADE_Cntrst(x,W);
        API_JADE(index) = API;       
        
        
        %Radical_ICA
        %disp('Radical ICA Contrast....');
        Cntrst_Radical(index) = Radical_Cntrst(x,W);
        API_Radical(index) = API; 
    
        %BetaD_ICA %QUESTION: MUST DO FOR MORE BETAS
        %disp('BetaD Contrast....');
        u = mean(x,2);
        p_i(1:2) = 1; %NOTE: 1 for subGaussian, 2 for SuperGuassian
        
        for i = 1:length(Betas)
            Cntrst_BetaD(i,index) = BetaD_Cntrst(x,W,u,Betas(i),p_i);
        end
         API_BetaD(index) = API;
        
    end
    
    if ~(isreal(sum(sum(Cntrst_FastICA)+Cntrst_Infomax+Cntrst_JADE+Cntrst_Radical+sum(Cntrst_BetaD))))
        warning('Non-real contrast');
        break;
    end
    
   Cntrst_ICA = [Cntrst_FastICA;API_FastICA;Cntrst_Infomax;API_Infomax;Cntrst_JADE;API_JADE;Cntrst_Radical;API_Radical;Cntrst_BetaD;API_BetaD];
  