%This program calls FastICA, Infomax, JADE, Radical and Beta-Divergence to performance ICA on data sets. 
%This file generates separates the data, and  calculates the Amari separation performance.
%
%Neil Gadhok, Mar 6, 2005, v1.0

function AmariPerf = ICCI05_Exp2_ICA_Caller(x,A,whiteningMatrix_sW)


AmariPerf = [];

%ICA Algorithms
    %NOTE: The observation x is assumed to have been prewhitened.
  
    %Common parameters to initialize
         Winit = (2*rand(2,2))-1;                      %Generates uniform distribution          
         Winit = Winit'*Winit + 2*eye(size(Winit,2));  %To ensure it is +ve definite
         uinit = mean(x,2);
       
    disp('Calculating ICA....');
         
    %FastICA %QUESTION: CHANGE TO INCLUDED OTHER NONLINEAR FUNCTIONS
        %disp('FastICA....'); %With whitening turned off
        [Ysig_FastICA,Aest_FastICA,West_FastICAG1] = fastica(x, 'whitesig',x, 'whiteMat', eye(2), 'deWhiteMat',eye(2), 'approach','symm','g','tanh','displayMode','off','verbose','off','a2',1,'stabilization','on','epsilon',1e-6,'maxNumIterations',150,'initGuess',Winit);
        [Ysig_FastICA,Aest_FastICA,West_FastICAG2] = fastica(x, 'whitesig',x, 'whiteMat', eye(2), 'deWhiteMat',eye(2), 'approach','symm','g','gauss','displayMode','off','verbose','off','a2',1,'stabilization','on','epsilon',1e-6,'maxNumIterations',150,'initGuess',Winit);
        [Ysig_FastICA,Aest_FastICA,West_FastICAG3] = fastica(x, 'whitesig',x, 'whiteMat', eye(2), 'deWhiteMat',eye(2), 'approach','symm','g','pow3','displayMode','off','verbose','off','a2',1,'stabilization','on','epsilon',1e-6,'maxNumIterations',150,'initGuess',Winit);
        [Ysig_FastICA,Aest_FastICA,West_FastICAG4] = fastica(x, 'whitesig',x, 'whiteMat', eye(2), 'deWhiteMat',eye(2), 'approach','symm','g','skew','displayMode','off','verbose','off','a2',1,'stabilization','on','epsilon',1e-6,'maxNumIterations',150,'initGuess',Winit);
                                
        %The nonlinearity must correspond to that used in the constrast function. Not sure if it is related to density, but more robustness? Used to approximate negentropy.
        %                       Value of 'g':      Nonlinearity used:       Value of 'G
        %G1                     'tanh'             g(u)=tanh(a1*u)          1/a1 * log(cosh(a1*y))
        %G2                     'gauss'            g(u)=u*exp(-a2*u^2/2)    - exp(-y^2/2)
        %G3                     'pow3' (default)   g(u)=u^3                 1/4 y^4  (kurtosis)
        %G4                     'skew'             g(u)=u^2

        
    %Infomax
        %disp('Infomax....'); %With whitening turned off
        [w_Infomax,sphere_Infomax] = ext_infomax_runica(x,'extended',-2,'sphering','off','verbose','off','weights',Winit);
        
    %JADE
        %disp('JADE....'); %With whitening turned off
        W_JADE=jadeR_mod1(x); 
        
    %Radical ICA
        %disp('Radical....'); %With whitening turned off
        [Yopt_Radical,Wopt_Radical]=radical_2d_mod1(x);
    
    %Beta Divergence %QUESTION: CHANGE TO INCLUDE MORE BETA VALUES
        %disp('Beta Divergence....');
        p_i(1:2) = 1;            %This tells us which p_i(z) to use for each source. NOTE: WHICH ONE SHOULD BE USED???
        Betas = [0,0.05,0.1,0.2,0.3];
        stopping_criterion = 1e-6;         
        maxiteration_BFGS = 25;            %Question how does this effect your Amari performance???
        maxiteration_linesearch = 20;

        [W_BetaD_0,u_BetaD_0,Wss_BetaD_0] = BetaD_ICA(x,Winit,uinit,Betas(1),stopping_criterion,maxiteration_BFGS,maxiteration_linesearch,p_i);
        [W_BetaD_05,u_BetaD_05,Wss_BetaD_05] = BetaD_ICA(x,Winit,uinit,Betas(2),stopping_criterion,maxiteration_BFGS,maxiteration_linesearch,p_i);
        [W_BetaD_1,u_BetaD_1,Wss_BetaD_1] = BetaD_ICA(x,Winit,uinit,Betas(3),stopping_criterion,maxiteration_BFGS,maxiteration_linesearch,p_i);
        [W_BetaD_2,u_BetaD_2,Wss_BetaD_2] = BetaD_ICA(x,Winit,uinit,Betas(4),stopping_criterion,maxiteration_BFGS,maxiteration_linesearch,p_i);
        [W_BetaD_3,u_BetaD_3,Wss_BetaD_3] = BetaD_ICA(x,Winit,uinit,Betas(5),stopping_criterion,maxiteration_BFGS,maxiteration_linesearch,p_i);    
    
%Analysis and plotting of results
    Amari_FastICAG1 = Amari(West_FastICAG1*whiteningMatrix_sW*A);
    Amari_FastICAG2 = Amari(West_FastICAG2*whiteningMatrix_sW*A);
    Amari_FastICAG3 = Amari(West_FastICAG3*whiteningMatrix_sW*A);
    Amari_FastICAG4 = Amari(West_FastICAG4*whiteningMatrix_sW*A);
    Amari_Infomax = Amari(w_Infomax*whiteningMatrix_sW*A);
    Amari_JADE    = Amari(W_JADE*whiteningMatrix_sW*A);
    Amari_Radical = Amari(Wopt_Radical*whiteningMatrix_sW*A);
    Amari_BetaD_0   = Amari(W_BetaD_0*whiteningMatrix_sW*A);
    Amari_BetaD_05  = Amari(W_BetaD_05*whiteningMatrix_sW*A);
    Amari_BetaD_1   = Amari(W_BetaD_1*whiteningMatrix_sW*A);
    Amari_BetaD_2   = Amari(W_BetaD_2*whiteningMatrix_sW*A);
    Amari_BetaD_3   = Amari(W_BetaD_3*whiteningMatrix_sW*A);
    
    
    AmariPerf = [Amari_FastICAG1;Amari_FastICAG2;Amari_FastICAG3;Amari_FastICAG4;Amari_Infomax;Amari_JADE;Amari_Radical;Amari_BetaD_0;Amari_BetaD_05;Amari_BetaD_1;Amari_BetaD_2;Amari_BetaD_3];