%ANALYSIS OF RESULTS
%This program: (1) Determines changes between the contrast with and without outliers.
%              (2) %Determine the median,mean and variance of the AmariPerf for the algorithms, and determine the median, mean and 1-norm of the error of the rotation angle from the contrast functions.
%
%Neil Gadhok, v1.0, Mar 6, 2005


%Cntrsts(A,B,C,D,E,F,G,H)
%Contrsts(1:10,        1:2 [100,200],    1:2 [0,45],  1:2 [0,1],    1:5 [0,1,3,5,7], 1 [0],     1:17,                1:50)
%Contrsts(NumTestRuns, NumSamples,       Rotation,    NumOutliers,  Outliers1,        Outliers2,Cntrst_FastICA_G1,1
%                                                                                               Cntrst_FastICA_G2,2
%                                                                                               Cntrst_FastICA_G3,3
%                                                                                               Cntrst_FastICA_G4,4
%                                                                                               API_FastICA,      5
%                                                                                               Cntrst_Infomax,   6
%                                                                                               API_Infomax,      7
%                                                                                               Cntrst_JADE,      8
%                                                                                               API_JADE,         9
%                                                                                               Cntrst_Radical,   10
%                                                                                               API_Radical,      11
%                                                                                               Cntrst_BetaD_0,   12
%                                                                                               Cntrst_BetaD_05,  13
%                                                                                               Cntrst_BetaD_1,   14
%                                                                                               Cntrst_BetaD_2,   15
%                                                                                               Cntrst_BetaD_3,   16
%                                                                                               API_BetaD,        17   


%Note: When NumOutliers = 1 [So, zero outliers), the only values solved for, is when Outliers1 = 1 [0] and Outliers2 = 1[0]

    
%AmariPerf(A,B,C,D,E,F,G,H)
%AmariPerf(1:10,        1:2 [100,200],    1:2 [0,45],  1:2 [0,1],    1:5 [0,1,3,5,7], 1 [0],   1:12,                1)
%AmariPerf(NumTestRuns, NumSamples,       Rotation,    NumOutliers,  Outliers,        Outliers,Cntrst_FastICA_G1,1
%                                                                                              Cntrst_FastICA_G2,2
%                                                                                              Cntrst_FastICA_G3,3
%                                                                                              Cntrst_FastICA_G4,4
%                                                                                              Cntrst_Infomax,   5
%                                                                                              Cntrst_JADE,      6
%                                                                                              Cntrst_Radical,   7
%                                                                                              Cntrst_BetaD_0,   8
%                                                                                              Cntrst_BetaD_05,  9
%                                                                                              Cntrst_BetaD_1,   10
%                                                                                              Cntrst_BetaD_2,   11
%                                                                                              Cntrst_BetaD_3,   12

%Note: When NumOutliers = 1 (So, zero outliers), the only values solved for, is when Outliers1 = 1 [0] and Outliers2 = 1[0]


clear all;
close all;
clc;

load 'e:\Thesis\Results\06-Mar-2005\Exp1\CCECE05_DataSet'
load 'e:\Thesis\Results\07-Mar-2005\Exp2\CCECE05_Cntrsts'
load 'e:\Thesis\Results\07-Mar-2005\Exp2\CCECE05_AmariPerf'


NumSamples = [100,200];  %Number of source samples
NumOutliers = [0,1]; %Number of outliers to introduce at the sensor
Rotation = [0,45]; %The different rotation matrices used to mix the sources.
Outliers = [0,1,3,5,7]; %The outlier is at 0,1,3,5, or 7 std deviations from the mean (Assuming symmteric, zero mean, unit variance distributions
NumTestRuns = 10;
theta = linspace(0,pi/2,50); %Must change 50 to = N
NoOutliersIndex = 1;

%Determine changes between the contrast with and without outliers.

     
i = 0;
for TestRun = 1:10,
 for NumSamplesIndex = 1:2, %100,200
     for RotationIndex = 1:2, %0, 45
         for NumOutliersIndex = 1:2,  %0,1
            for Source1OutlierIndex = 1:5, %0,1,3,5,7
                Source2OutlierIndex = 1;
                close all; %Close all windows
                
                %FastICA (G1)
     
                 %Absolute Error between the contrast with outliers and no outliers
                   Cntrsts_Absolute_Diff(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,1,:) = Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,1,:) - Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,1,:);
                   Cntrsts_Absolute_NormInf_Diff(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,1,:) = norm(squeeze(Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,1,:) - Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,1,:)),inf);
                   Cntrsts_Absolute_MSE(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,1,:) = (Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,1,:) - mean(Cntrsts_Absolute_Diff(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,1,:))).^2;
                   
                 %Normalize
                   TempNormOutliers = squeeze(Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,1,:));
                   TempNormOutliers = TempNormOutliers + min(abs(TempNormOutliers));
                   if (max(abs(TempNormOutliers)) ~= 0)  TempNormOutliers = TempNormOutliers./max(abs(TempNormOutliers)); end
                   TempNormNoOutliers = squeeze(Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,1,:));
                   TempNormNoOutliers = TempNormNoOutliers + min(abs(TempNormNoOutliers));
                   if (max(abs(TempNormNoOutliers)) ~= 0)  TempNormNoOutliers = TempNormNoOutliers./max(abs(TempNormNoOutliers)); end
                   
                
                   %Align contrasts at the minimum (to determine shape error)
                   [d1,d2] = min(TempNormOutliers);
                   [e1,e2] = min(TempNormNoOutliers);
                   TempNormOutliers = [TempNormOutliers(d2:end);TempNormOutliers(1:d2-1)];
                   TempNormNoOutliers = [TempNormNoOutliers(e2:end);TempNormNoOutliers(1:e2-1)];
                   
                   Cntrsts_Norm_Diff(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,1,:) = TempNormOutliers - TempNormNoOutliers;
                  
                   
             
                 %FastICA (G2)    
  
                 %Absolute Error between the contrast with outliers and no outliers
                   Cntrsts_Absolute_Diff(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,2,:) = Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,2,:) - Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,2,:);                 
                   Cntrsts_Absolute_NormInf_Diff(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,2,:) = norm(squeeze(Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,2,:) - Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,2,:)),inf);
                   Cntrsts_Absolute_MSE(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,2,:) = (Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,2,:) - mean(Cntrsts_Absolute_Diff(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,2,:))).^2;
                   
                 %Normalize for plot
                   TempNormOutliers = squeeze(Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,2,:));
                   TempNormOutliers = TempNormOutliers + min(abs(TempNormOutliers));
                   if (max(abs(TempNormOutliers)) ~= 0)  TempNormOutliers = TempNormOutliers./max(abs(TempNormOutliers)); end
                   TempNormNoOutliers = squeeze(Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,2,:));
                   TempNormNoOutliers = TempNormNoOutliers + min(abs(TempNormNoOutliers));
                   if (max(abs(TempNormNoOutliers)) ~= 0)   TempNormNoOutliers = TempNormNoOutliers./max(abs(TempNormNoOutliers)); end
                  
                   
                   %Align contrasts at the minimum (to determine shape error)
                   [d1,d2] = min(TempNormOutliers);
                   [e1,e2] = min(TempNormNoOutliers);
                   TempNormOutliers = [TempNormOutliers(d2:end);TempNormOutliers(1:d2-1)];
                   TempNormNoOutliers = [TempNormNoOutliers(e2:end);TempNormNoOutliers(1:e2-1)];
                   Cntrsts_Norm_Diff(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,2,:) = TempNormOutliers - TempNormNoOutliers;                 
                   
                   
                   
                 %FastICA (G3)    
                 
                 %Absolute Error between the contrast with outliers and no outliers
                   Cntrsts_Absolute_Diff(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,3,:) = Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,3,:) - Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,3,:);                 
                   Cntrsts_Absolute_NormInf_Diff(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,3,:) = norm(squeeze(Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,3,:) - Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,3,:)),inf);                                  
                   Cntrsts_Absolute_MSE(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,3,:) = (Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,3,:) - mean(Cntrsts_Absolute_Diff(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,3,:))).^2;
                   
                 %Normalize for plot
                   TempNormOutliers = squeeze(Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,3,:));
                   TempNormOutliers = TempNormOutliers + min(abs(TempNormOutliers));
                   if (max(abs(TempNormOutliers)) ~= 0)  TempNormOutliers = TempNormOutliers./max(abs(TempNormOutliers)); end
                   TempNormNoOutliers = squeeze(Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,3,:));
                   TempNormNoOutliers = TempNormNoOutliers + min(abs(TempNormNoOutliers));
                   if (max(abs(TempNormNoOutliers)) ~= 0)  TempNormNoOutliers = TempNormNoOutliers./max(abs(TempNormNoOutliers)); end
                   
                   
                   %Align contrasts at the minimum (to determine shape error)
                   [d1,d2] = min(TempNormOutliers);
                   [e1,e2] = min(TempNormNoOutliers);
                   TempNormOutliers = [TempNormOutliers(d2:end);TempNormOutliers(1:d2-1)];
                   TempNormNoOutliers = [TempNormNoOutliers(e2:end);TempNormNoOutliers(1:e2-1)];
                   Cntrsts_Norm_Diff(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,3,:) = TempNormOutliers - TempNormNoOutliers;                 
                   
                 %FastICA (G4)    
                 
                  %Absolute Error between the contrast with outliers and no outliers
                    Cntrsts_Absolute_Diff(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,4,:) = Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,4,:) - Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,4,:);
                    Cntrsts_Absolute_NormInf_Diff(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,4,:) = norm(squeeze(Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,4,:) - Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,4,:)),inf);                    
                    Cntrsts_Absolute_MSE(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,4,:) = (Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,4,:) - mean(Cntrsts_Absolute_Diff(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,4,:))).^2;
                    
                 %Normalize for plot
                   TempNormOutliers = squeeze(Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,4,:));
                   TempNormOutliers = TempNormOutliers + min(abs(TempNormOutliers));
                   if (max(abs(TempNormOutliers)) ~= 0)  TempNormOutliers = TempNormOutliers./max(abs(TempNormOutliers)); end
                   TempNormNoOutliers = squeeze(Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,4,:));
                   TempNormNoOutliers = TempNormNoOutliers + min(abs(TempNormNoOutliers));
                   if (max(abs(TempNormNoOutliers)) ~= 0)  TempNormNoOutliers = TempNormNoOutliers./max(abs(TempNormNoOutliers)); end
                      
                   %Align contrasts at the minimum (to determine shape error)
                   [d1,d2] = min(TempNormOutliers);
                   [e1,e2] = min(TempNormNoOutliers);
                   TempNormOutliers = [TempNormOutliers(d2:end);TempNormOutliers(1:d2-1)];
                   TempNormNoOutliers = [TempNormNoOutliers(e2:end);TempNormNoOutliers(1:e2-1)];                   
                   Cntrsts_Norm_Diff(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,4,:) = TempNormOutliers - TempNormNoOutliers;    
                   
                   
                 %FastICA (Amari) %Just to check, Not sure if - or +
                    %Absolute Error between the contrast with outliers and no outliers
                    Cntrsts_Absolute_Diff(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,5,:) = Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,5,:) - Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,5,:);    
                    Cntrsts_Absolute_NormInf_Diff(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,5,:) = norm(squeeze(Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,5,:) - Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,5,:)),inf);                 
                    Cntrsts_Absolute_MSE(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,5,:) = (Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,5,:) - mean(Cntrsts_Absolute_Diff(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,5,:))).^2;
                    
                 %Normalize for plot %It should already be normalized (kinda)
                    Cntrsts_Norm_Diff(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,5,:) = Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,5,:) - Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,5,:);    
                   
                 
                
                 %Infomax
                 
                 %Absolute Error between the contrast with outliers and no outliers
                    Cntrsts_Absolute_Diff(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,6,:) = Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,6,:) - Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,6,:);    
                    Cntrsts_Absolute_NormInf_Diff(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,6,:) = norm(squeeze(Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,6,:) - Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,6,:)),inf);                    
                    Cntrsts_Absolute_MSE(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,6,:) = (Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,6,:) - mean(Cntrsts_Absolute_Diff(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,6,:))).^2;
                    
                 %Normalize for plot
                   TempNormOutliers = squeeze(Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,6,:));
                   TempNormOutliers = TempNormOutliers - min(abs(TempNormOutliers));
                   if (max(abs(TempNormOutliers)) ~= 0)   TempNormOutliers = TempNormOutliers./max(abs(TempNormOutliers)); end
                   TempNormNoOutliers = squeeze(Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,6,:));
                   TempNormNoOutliers = TempNormNoOutliers - min(abs(TempNormNoOutliers));
                   if (max(abs(TempNormNoOutliers)) ~= 0)  TempNormNoOutliers = TempNormNoOutliers./max(abs(TempNormNoOutliers)); end
                 
                   %Align contrasts at the minimum (to determine shape error)
                   [d1,d2] = min(TempNormOutliers);
                   [e1,e2] = min(TempNormNoOutliers);
                   TempNormOutliers = [TempNormOutliers(d2:end);TempNormOutliers(1:d2-1)];
                   TempNormNoOutliers = [TempNormNoOutliers(e2:end);TempNormNoOutliers(1:e2-1)];                   
                   Cntrsts_Norm_Diff(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,6,:) = TempNormOutliers - TempNormNoOutliers;    
                   
                   
                 %JADE

                 %Absolute Error between the contrast with outliers and no outliers
                    Cntrsts_Absolute_Diff(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,8,:) = Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,8,:) - Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,8,:);    
                    Cntrsts_Absolute_NormInf_Diff(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,8,:) = norm(squeeze(Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,8,:) - Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,8,:)),inf);                 
                    Cntrsts_Absolute_MSE(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,8,:) = (Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,8,:) - mean(Cntrsts_Absolute_Diff(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,8,:))).^2;
                    
                 %Normalize for plot
                   TempNormOutliers = squeeze(Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,8,:));
                   TempNormOutliers = TempNormOutliers - min(abs(TempNormOutliers));
                   if (max(abs(TempNormOutliers)) ~= 0)  TempNormOutliers = TempNormOutliers./max(abs(TempNormOutliers)); end
                   TempNormNoOutliers = squeeze(Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,8,:));
                   TempNormNoOutliers = TempNormNoOutliers - min(abs(TempNormNoOutliers));
                   if (max(abs(TempNormNoOutliers)) ~= 0)  TempNormNoOutliers = TempNormNoOutliers./max(abs(TempNormNoOutliers)); end
                 
                   %Align contrasts at the minimum (to determine shape error)
                   [d1,d2] = min(TempNormOutliers);
                   [e1,e2] = min(TempNormNoOutliers);
                   TempNormOutliers = [TempNormOutliers(d2:end);TempNormOutliers(1:d2-1)];
                   TempNormNoOutliers = [TempNormNoOutliers(e2:end);TempNormNoOutliers(1:e2-1)];                   
  		           Cntrsts_Norm_Diff(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,8,:) = TempNormOutliers - TempNormNoOutliers;    
                   
                   
                 %Radical
                 
                 %Absolute Error between the contrast with outliers and no outliers
                    Cntrsts_Absolute_Diff(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,10,:) = Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,10,:) - Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,10,:);    
                    Cntrsts_Absolute_NormInf_Diff(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,10,:) = norm(squeeze(Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,10,:) - Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,10,:)),inf);                 
                    Cntrsts_Absolute_MSE(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,10,:) = (Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,10,:) - mean(Cntrsts_Absolute_Diff(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,10,:))).^2;                 

                 %Normalize for plot
                   TempNormOutliers = squeeze(Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,10,:));
                   TempNormOutliers = TempNormOutliers - min(abs(TempNormOutliers));
                   if (max(abs(TempNormOutliers)) ~= 0)  TempNormOutliers = TempNormOutliers./max(abs(TempNormOutliers)); end
                   TempNormNoOutliers = squeeze(Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,10,:));
                   TempNormNoOutliers = TempNormNoOutliers - min(abs(TempNormNoOutliers));
                   if (max(abs(TempNormNoOutliers)) ~= 0)  TempNormNoOutliers = TempNormNoOutliers./max(abs(TempNormNoOutliers)); end

                   %Align contrasts at the minimum (to determine shape error)
                   [d1,d2] = min(TempNormOutliers);
                   [e1,e2] = min(TempNormNoOutliers);
                   TempNormOutliers = [TempNormOutliers(d2:end);TempNormOutliers(1:d2-1)];
                   TempNormNoOutliers = [TempNormNoOutliers(e2:end);TempNormNoOutliers(1:e2-1)];                   
                   Cntrsts_Norm_Diff(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,10,:) = TempNormOutliers - TempNormNoOutliers;    
                   
                 
                 %BetaD B=0
                 
                 %Absolute Error between the contrast with outliers and no outliers
                    Cntrsts_Absolute_Diff(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,12,:) = Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,12,:) - Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,12,:);    
                    Cntrsts_Absolute_NormInf_Diff(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,12,:) = norm(squeeze(Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,12,:) - Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,12,:)),inf);                                  
                    Cntrsts_Absolute_MSE(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,12,:) = (Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,12,:) - mean(Cntrsts_Absolute_Diff(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,12,:))).^2;
                    
                 %Normalize for plot
                   TempNormOutliers = squeeze(Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,12,:));
                   TempNormOutliers = TempNormOutliers - min(abs(TempNormOutliers));
                   if (max(abs(TempNormOutliers)) ~= 0)  TempNormOutliers = TempNormOutliers./max(abs(TempNormOutliers)); end
                   TempNormNoOutliers = squeeze(Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,12,:));
                   TempNormNoOutliers = TempNormNoOutliers - min(abs(TempNormNoOutliers));
                   if (max(abs(TempNormNoOutliers)) ~= 0)  TempNormNoOutliers = TempNormNoOutliers./max(abs(TempNormNoOutliers)); end

                  %Align contrasts at the minimum (to determine shape error)
                  [d1,d2] = min(TempNormOutliers);
                  [e1,e2] = min(TempNormNoOutliers);
                  TempNormOutliers = [TempNormOutliers(d2:end);TempNormOutliers(1:d2-1)];
                  TempNormNoOutliers = [TempNormNoOutliers(e2:end);TempNormNoOutliers(1:e2-1)];
                  Cntrsts_Norm_Diff(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,12,:) = TempNormOutliers - TempNormNoOutliers;    

                   
                 %BetaD B=0.05
                 
                 %Absolute Error between the contrast with outliers and no outliers
                    Cntrsts_Absolute_Diff(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,13,:) = Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,13,:) - Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,13,:);    
                    Cntrsts_Absolute_NormInf_Diff(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,13,:) = norm(squeeze(Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,13,:) - Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,13,:)),inf);                 
                    Cntrsts_Absolute_MSE(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,13,:) = (Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,13,:) - mean(Cntrsts_Absolute_Diff(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,13,:))).^2;
                    
                 %Normalize for plot
                   TempNormOutliers = squeeze(Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,13,:));
                   TempNormOutliers = TempNormOutliers - min(abs(TempNormOutliers));
                   if (max(abs(TempNormOutliers)) ~= 0)  TempNormOutliers = TempNormOutliers./max(abs(TempNormOutliers)); end
                   TempNormNoOutliers = squeeze(Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,13,:));
                   TempNormNoOutliers = TempNormNoOutliers - min(abs(TempNormNoOutliers));
                   if (max(abs(TempNormNoOutliers)) ~= 0)  TempNormNoOutliers = TempNormNoOutliers./max(abs(TempNormNoOutliers)); end
                   
                   %Align contrasts at the minimum (to determine shape error)
                   [d1,d2] = min(TempNormOutliers);
                   [e1,e2] = min(TempNormNoOutliers);
                   TempNormOutliers = [TempNormOutliers(d2:end);TempNormOutliers(1:d2-1)];
                   TempNormNoOutliers = [TempNormNoOutliers(e2:end);TempNormNoOutliers(1:e2-1)];                 
                   Cntrsts_Norm_Diff(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,13,:) = TempNormOutliers - TempNormNoOutliers;                       
                 
                 %BetaD B=0.1

                 %Absolute Error between the contrast with outliers and no outliers
                    Cntrsts_Absolute_Diff(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,14,:) = Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,14,:) - Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,14,:);    
                    Cntrsts_Absolute_NormInf_Diff(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,14,:) = norm(squeeze(Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,14,:) - Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,14,:)),inf);
                    Cntrsts_Absolute_MSE(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,14,:) = (Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,14,:) - mean(Cntrsts_Absolute_Diff(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,14,:))).^2;                 

                   %Normalize for plot
                   TempNormOutliers = squeeze(Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,14,:));
                   TempNormOutliers = TempNormOutliers - min(abs(TempNormOutliers));
                   if (max(abs(TempNormOutliers)) ~= 0)  TempNormOutliers = TempNormOutliers./max(abs(TempNormOutliers)); end
                   TempNormNoOutliers = squeeze(Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,14,:));
                   TempNormNoOutliers = TempNormNoOutliers - min(abs(TempNormNoOutliers));
                   if (max(abs(TempNormNoOutliers)) ~= 0)  TempNormNoOutliers = TempNormNoOutliers./max(abs(TempNormNoOutliers)); end
                 
                   
                   %Align contrasts at the minimum (to determine shape error)
                   [d1,d2] = min(TempNormOutliers);
                   [e1,e2] = min(TempNormNoOutliers);
                   TempNormOutliers = [TempNormOutliers(d2:end);TempNormOutliers(1:d2-1)];
                   TempNormNoOutliers = [TempNormNoOutliers(e2:end);TempNormNoOutliers(1:e2-1)];                   
                   Cntrsts_Norm_Diff(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,14,:) = TempNormOutliers - TempNormNoOutliers;                       
                   
                 %BetaD B=0.2
                 
                 %Absolute Error between the contrast with outliers and no outliers
                    Cntrsts_Absolute_Diff(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,15,:) = Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,15,:) - Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,15,:);    
                    Cntrsts_Absolute_NormInf_Diff(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,15,:) = norm(squeeze(Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,15,:) - Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,15,:)),inf);                 
                    Cntrsts_Absolute_MSE(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,15,:) = (Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,15,:) - mean(Cntrsts_Absolute_Diff(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,15,:))).^2;
                    
                 %Normalize for plot
                   TempNormOutliers = squeeze(Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,15,:));
                   TempNormOutliers = TempNormOutliers - min(abs(TempNormOutliers));
                   if (max(abs(TempNormOutliers)) ~= 0)  TempNormOutliers = TempNormOutliers./max(abs(TempNormOutliers)); end
                   TempNormNoOutliers = squeeze(Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,15,:));
                   TempNormNoOutliers = TempNormNoOutliers - min(abs(TempNormNoOutliers));
                   if (max(abs(TempNormNoOutliers)) ~= 0)  TempNormNoOutliers = TempNormNoOutliers./max(abs(TempNormNoOutliers)); end
                 
                   
                   %Align contrasts at the minimum (to determine shape error)
                   [d1,d2] = min(TempNormOutliers);
                   [e1,e2] = min(TempNormNoOutliers);
                   TempNormOutliers = [TempNormOutliers(d2:end);TempNormOutliers(1:d2-1)];
                   TempNormNoOutliers = [TempNormNoOutliers(e2:end);TempNormNoOutliers(1:e2-1)];                   
                   Cntrsts_Norm_Diff(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,15,:) = TempNormOutliers - TempNormNoOutliers;                                        
                   
                 %BetaD B =0.3
                 
                 %Absolute Error between the contrast with outliers and no outliers
                    Cntrsts_Absolute_Diff(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,16,:) = Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,16,:) - Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,16,:);    
                    Cntrsts_Absolute_NormInf_Diff(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,16,:) = norm(squeeze(Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,16,:) - Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,16,:)),inf);                  
                    Cntrsts_Absolute_MSE(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,16,:) = (Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,16,:) - mean(Cntrsts_Absolute_Diff(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,16,:))).^2;
                    
                   %Normalize for plot
                   TempNormOutliers = squeeze(Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,16,:));
                   TempNormOutliers = TempNormOutliers - min(abs(TempNormOutliers));
                   if (max(abs(TempNormOutliers)) ~= 0)  TempNormOutliers = TempNormOutliers./max(abs(TempNormOutliers)); end
                   TempNormNoOutliers = squeeze(Cntrsts(TestRun,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,16,:));
                   TempNormNoOutliers = TempNormNoOutliers - min(abs(TempNormNoOutliers));
                   if (max(abs(TempNormNoOutliers)) ~= 0)  TempNormNoOutliers = TempNormNoOutliers./max(abs(TempNormNoOutliers)); end
                 
                   
                   %Align contrasts at the minimum (to determine shape error)
                   [d1,d2] = min(TempNormOutliers);
                   [e1,e2] = min(TempNormNoOutliers);
                   TempNormOutliers = [TempNormOutliers(d2:end);TempNormOutliers(1:d2-1)];
                   TempNormNoOutliers = [TempNormNoOutliers(e2:end);TempNormNoOutliers(1:e2-1)];                   
                   Cntrsts_Norm_Diff(TestRun,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,16,:) = TempNormOutliers - TempNormNoOutliers;                                        
                   
                   
              end %for Source1OutlierIndex = 1:5, %0,1,3,5,7
            
        end % for NumOutliersIndex = 1:5  %0,1,3,5,7
   
    end% for RotationIndex = 1:2, %0, 45
    
end %NumSamplesIndex = 1:2, %100,200

end %for TestRun = 1:10,





%Determine the median,mean and variance of the AmariPerf for the algorithms, and determine the median, mean and 1-norm of the error of the rotation angle from the contrast functions.
i = 0;
 for NumSamplesIndex = 1:2, %100,200
     for RotationIndex = 1:2, %0, 45
         for NumOutliersIndex = 1:2,  %0,1
            for Source1OutlierIndex = 1:5, %0,1,3,5,7
                Source2OutlierIndex = 1;
                close all; %Close all windows
                
                
                if (NumOutliersIndex == 1) & (Source1OutlierIndex == 1), %No Outliers
                        i = i+1;
                        FastICA_G1(i,1:3) = [median(AmariPerf(:,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,1)),
                                     mean(AmariPerf(:,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,1)), 
                                     var(AmariPerf(:,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,1))
                                    ]';  
                        FastICA_G2(i,1:3) = [median(AmariPerf(:,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,2)),
                                     mean(AmariPerf(:,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,2)), 
                                     var(AmariPerf(:,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,2))
                                    ]';  
                        FastICA_G3(i,1:3) = [median(AmariPerf(:,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,3)),
                                     mean(AmariPerf(:,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,3)), 
                                     var(AmariPerf(:,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,3))
                                    ]';  
                        FastICA_G4(i,1:3) = [median(AmariPerf(:,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,4)),
                                     mean(AmariPerf(:,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,4)), 
                                     var(AmariPerf(:,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,4))
                                    ]'; 
                        Ext_Infomax(i,1:3) = [median(AmariPerf(:,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,5)),
                                     mean(AmariPerf(:,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,5)), 
                                     var(AmariPerf(:,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,5))
                                    ]';  
                        JADE(i,1:3) = [median(AmariPerf(:,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,6)),
                                     mean(AmariPerf(:,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,6)), 
                                     var(AmariPerf(:,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,6))
                                    ]';  
                        Radical(i,1:3) = [median(AmariPerf(:,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,7)),
                                     mean(AmariPerf(:,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,7)), 
                                     var(AmariPerf(:,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,7))
                                    ]';  
                        BetaD_0(i,1:3) = [median(AmariPerf(:,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,8)),
                                     mean(AmariPerf(:,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,8)), 
                                     var(AmariPerf(:,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,8))
                                    ]';  
                        BetaD_05(i,1:3) = [median(AmariPerf(:,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,9)),
                                     mean(AmariPerf(:,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,9)), 
                                     var(AmariPerf(:,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,9))
                                    ]';  
                        BetaD_1(i,1:3) = [median(AmariPerf(:,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,10)),
                                     mean(AmariPerf(:,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,10)), 
                                     var(AmariPerf(:,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,10))
                                    ]';  
                        BetaD_2(i,1:3) = [median(AmariPerf(:,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,11)),
                                     mean(AmariPerf(:,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,11)), 
                                     var(AmariPerf(:,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,11))
                                    ]';  
                        BetaD_3(i,1:3) = [median(AmariPerf(:,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,12)),
                                     mean(AmariPerf(:,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,12)), 
                                     var(AmariPerf(:,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,12))
                                    ]';  
                                    
                 
                                    
                        %No Outliers
                        clear p; %dummy variable
                        clear q; %dummy variable
                        
                        for j = 1:NumTestRuns,
                           [p(j,:),q(j,:)] = min(squeeze(Cntrsts(j,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,1:5,:))'); %q contains the indices of the minimum value from the contrast
                        end
                        RotationErrorNoOutliers = rad2deg(theta(q)) - rad2deg(theta(q(:,5)*ones(1,5)));
                        RotationErrorNoOutliers = RotationErrorNoOutliers - 2*mod(RotationErrorNoOutliers.*(RotationErrorNoOutliers > 45),45); %Make angles > 45 less than 45
                        RotationErrorNoOutliers = RotationErrorNoOutliers - 2*mod(RotationErrorNoOutliers.*(RotationErrorNoOutliers < -45),-45); %Make angles < -45 greater than -45
                        RotationErrorNoOutliers =  sign(RotationErrorNoOutliers).*mod(abs(RotationErrorNoOutliers),90); %Make errors of 90 = angles of 0
                        
                       
                        FastICA_G1(i,4:6)  = [median(RotationErrorNoOutliers(:,1)),
                                              mean(RotationErrorNoOutliers(:,1)), 
                                              norm(RotationErrorNoOutliers(:,1),1)
                                             ]'; 
                        FastICA_G2(i,4:6)  = [median(RotationErrorNoOutliers(:,2)),
                                              mean(RotationErrorNoOutliers(:,2)), 
                                              norm(RotationErrorNoOutliers(:,2),1)
                                             ]';                                              
                        FastICA_G3(i,4:6)  = [median(RotationErrorNoOutliers(:,3)),
                                              mean(RotationErrorNoOutliers(:,3)), 
                                              norm(RotationErrorNoOutliers(:,3),1)
                                             ]';
                        FastICA_G4(i,4:6)  = [median(RotationErrorNoOutliers(:,4)),
                                              mean(RotationErrorNoOutliers(:,4)), 
                                              norm(RotationErrorNoOutliers(:,4),1)
                                             ]';
                                             
                        %No Outliers
                        clear p; %dummy variable
                        clear q; %dummy variable
                          
                        for j = 1:NumTestRuns,
                            [p(j,:),q(j,:)] = min(squeeze(Cntrsts(j,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,[6,7,8,10],:))');
                        end
                        RotationErrorNoOutliers = rad2deg(theta(q)) - rad2deg(theta(q(:,2)*ones(1,4)));
                        RotationErrorNoOutliers = RotationErrorNoOutliers - 2*mod(RotationErrorNoOutliers.*(RotationErrorNoOutliers > 45),45); %Make angles > 45 less than 45
                        RotationErrorNoOutliers = RotationErrorNoOutliers - 2*mod(RotationErrorNoOutliers.*(RotationErrorNoOutliers < -45),-45); %Make angles < -45 greater than -45
                        RotationErrorNoOutliers =  sign(RotationErrorNoOutliers).*mod(abs(RotationErrorNoOutliers),90);
                                                                       
                                             
                                             
                        Ext_Infomax(i,4:6) = [median(RotationErrorNoOutliers(:,1)),
                                              mean(RotationErrorNoOutliers(:,1)), 
                                              norm(RotationErrorNoOutliers(:,1),1)
                                             ]';
                        JADE(i,4:6)        = [median(RotationErrorNoOutliers(:,3)),
                                              mean(RotationErrorNoOutliers(:,3)), 
                                              norm(RotationErrorNoOutliers(:,3),1)
                                             ]'; 
                        Radical(i,4:6)     = [median(RotationErrorNoOutliers(:,4)),
                                              mean(RotationErrorNoOutliers(:,4)), 
                                              norm(RotationErrorNoOutliers(:,4),1)
                                             ]'; 
                                             
                        %No Outliers
                        clear p; %dummy variable
                        clear q; %dummy variable
                        for j = 1:NumTestRuns,
                           [p(j,:),q(j,:)] = min(squeeze(Cntrsts(j,NumSamplesIndex,RotationIndex,NoOutliersIndex,1,1,12:17,:))');
                        end
                        RotationErrorNoOutliers = rad2deg(theta(q)) - rad2deg(theta(q(:,6)*ones(1,6)));
                        RotationErrorNoOutliers = RotationErrorNoOutliers - 2*mod(RotationErrorNoOutliers.*(RotationErrorNoOutliers > 45),45); %Make angles > 45 less than 45
                        RotationErrorNoOutliers = RotationErrorNoOutliers - 2*mod(RotationErrorNoOutliers.*(RotationErrorNoOutliers < -45),-45); %Make angles < -45 greater than -45
                        RotationErrorNoOutliers =  sign(RotationErrorNoOutliers).*mod(abs(RotationErrorNoOutliers),90);
                                                     
                                             
                        BetaD_0(i,4:6)     = [median(RotationErrorNoOutliers(:,1)),
                                              mean(RotationErrorNoOutliers(:,1)), 
                                              norm(RotationErrorNoOutliers(:,1),1)
                                             ]'; 
                        BetaD_05(i,4:6)    = [median(RotationErrorNoOutliers(:,2)),
                                              mean(RotationErrorNoOutliers(:,2)), 
                                              norm(RotationErrorNoOutliers(:,2),1)
                                             ]'; 
                        BetaD_1(i,4:6)     = [median(RotationErrorNoOutliers(:,3)),
                                              mean(RotationErrorNoOutliers(:,3)), 
                                              norm(RotationErrorNoOutliers(:,3),1)
                                             ]'; 
                        BetaD_2(i,4:6)     = [median(RotationErrorNoOutliers(:,4)),
                                              mean(RotationErrorNoOutliers(:,4)), 
                                              norm(RotationErrorNoOutliers(:,4),1)
                                             ]'; 
                        BetaD_3(i,4:6)     = [median(RotationErrorNoOutliers(:,5)),
                                              mean(RotationErrorNoOutliers(:,5)), 
                                              norm(RotationErrorNoOutliers(:,5),1)
                                             ]';                                              
                                             
                                             
                                     
                elseif (NumOutliersIndex == 2), %Outliers
                    i = i+1;
                    FastICA_G1(i,1:3) = [median(AmariPerf(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,1)),
                                   mean(AmariPerf(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,1)),
                                   var(AmariPerf(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,1))
                                  ]';
                    FastICA_G2(i,1:3) = [median(AmariPerf(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,2)),
                                 mean(AmariPerf(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,2)), 
                                 var(AmariPerf(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,2))
                                ]';  
                    FastICA_G3(i,1:3) = [median(AmariPerf(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,3)),
                                 mean(AmariPerf(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,3)), 
                                 var(AmariPerf(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,3))
                                ]';  
                    FastICA_G4(i,1:3) = [median(AmariPerf(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,4)),
                                 mean(AmariPerf(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,4)), 
                                 var(AmariPerf(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,4))
                                ]'; 
                    Ext_Infomax(i,1:3) = [median(AmariPerf(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,5)),
                                 mean(AmariPerf(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,5)), 
                                 var(AmariPerf(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,5))
                                ]';  
                    JADE(i,1:3) = [median(AmariPerf(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,6)),
                                 mean(AmariPerf(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,6)), 
                                 var(AmariPerf(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,6))
                                ]';  
                    Radical(i,1:3) = [median(AmariPerf(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,7)),
                                 mean(AmariPerf(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,7)), 
                                 var(AmariPerf(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,7))
                                ]';  
                    BetaD_0(i,1:3) = [median(AmariPerf(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,8)),
                                 mean(AmariPerf(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,8)), 
                                 var(AmariPerf(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,8))
                                ]';  
                    BetaD_05(i,1:3) = [median(AmariPerf(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,9)),
                                 mean(AmariPerf(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,9)), 
                                 var(AmariPerf(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,9))
                                ]';  
                    BetaD_1(i,1:3) = [median(AmariPerf(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,10)),
                                 mean(AmariPerf(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,10)), 
                                 var(AmariPerf(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,10))
                                ]';  
                    BetaD_2(i,1:3) = [median(AmariPerf(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,11)),
                                 mean(AmariPerf(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,11)), 
                                 var(AmariPerf(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,11))
                                ]';  
                    BetaD_3(i,1:3) = [median(AmariPerf(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,12)),
                                 mean(AmariPerf(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,12)), 
                                 var(AmariPerf(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,12))
                                ]'; 
                                
                    %Outliers
                    clear p; %dummy variable
                    clear q; %dummy variable
                    
                    for j = 1:NumTestRuns,
                       [p(j,:),q(j,:)] = min(squeeze(Cntrsts(j,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,1:5,:))');
                    end
                    RotationErrorOutliers = rad2deg(theta(q)) - rad2deg(theta(q(:,5)*ones(1,5)));
                    RotationErrorOutliers = RotationErrorOutliers - 2*mod(RotationErrorOutliers.*(RotationErrorOutliers > 45),45); %Make angles > 45 less than 45
                    RotationErrorOutliers = RotationErrorOutliers - 2*mod(RotationErrorOutliers.*(RotationErrorOutliers < -45),-45); %Make angles < -45 greater than -45
                    RotationErrorOutliers =  sign(RotationErrorOutliers).*mod(abs(RotationErrorOutliers),90);
                    
                   
                    FastICA_G1(i,4:6)  = [median(RotationErrorOutliers(:,1)),
                                          mean(RotationErrorOutliers(:,1)), 
                                          norm(RotationErrorOutliers(:,1),1)
                                         ]'; 
                    FastICA_G2(i,4:6)  = [median(RotationErrorOutliers(:,2)),
                                          mean(RotationErrorOutliers(:,2)), 
                                          norm(RotationErrorOutliers(:,2),1)
                                         ]';                                              
                    FastICA_G3(i,4:6)  = [median(RotationErrorOutliers(:,3)),
                                          mean(RotationErrorOutliers(:,3)), 
                                          norm(RotationErrorOutliers(:,3),1)
                                         ]';
                    FastICA_G4(i,4:6)  = [median(RotationErrorOutliers(:,4)),
                                          mean(RotationErrorOutliers(:,4)), 
                                          norm(RotationErrorOutliers(:,4),1)
                                         ]';
                                         
                    %Outliers
                    clear p; %dummy variable
                    clear q; %dummy variable
                      
                    for j = 1:NumTestRuns,
                        [p(j,:),q(j,:)] = min(squeeze(Cntrsts(j,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,[6,7,8,10],:))');
                    end
                    RotationErrorOutliers = rad2deg(theta(q)) - rad2deg(theta(q(:,2)*ones(1,4)));
                    RotationErrorOutliers = RotationErrorOutliers - 2*mod(RotationErrorOutliers.*(RotationErrorOutliers > 45),45); %Make angles > 45 less than 45
                    RotationErrorOutliers = RotationErrorOutliers - 2*mod(RotationErrorOutliers.*(RotationErrorOutliers < -45),-45); %Make angles < -45 greater than -45
                    RotationErrorOutliers =  sign(RotationErrorOutliers).*mod(abs(RotationErrorOutliers),90);
                                                                   
                                         
                                         
                    Ext_Infomax(i,4:6) = [median(RotationErrorOutliers(:,1)),
                                          mean(RotationErrorOutliers(:,1)), 
                                          norm(RotationErrorOutliers(:,1),1)
                                         ]';
                    JADE(i,4:6)        = [median(RotationErrorOutliers(:,3)),
                                          mean(RotationErrorOutliers(:,3)), 
                                          norm(RotationErrorOutliers(:,3),1)
                                         ]'; 
                    Radical(i,4:6)     = [median(RotationErrorOutliers(:,4)),
                                          mean(RotationErrorOutliers(:,4)), 
                                          norm(RotationErrorOutliers(:,4),1)
                                         ]'; 
                                         
                    %Outliers
                    clear p; %dummy variable
                    clear q; %dummy variable
                    for j = 1:NumTestRuns,
                       [p(j,:),q(j,:)] = min(squeeze(Cntrsts(j,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,12:17,:))');
                    end
                    RotationErrorOutliers = rad2deg(theta(q)) - rad2deg(theta(q(:,6)*ones(1,6)));
                    RotationErrorOutliers = RotationErrorOutliers - 2*mod(RotationErrorOutliers.*(RotationErrorOutliers > 45),45); %Make angles > 45 less than 45
                    RotationErrorOutliers = RotationErrorOutliers - 2*mod(RotationErrorOutliers.*(RotationErrorOutliers < -45),-45); %Make angles < -45 greater than -45
                    RotationErrorOutliers =  sign(RotationErrorOutliers).*mod(abs(RotationErrorOutliers),90);
                                                 
                                         
                    BetaD_0(i,4:6)     = [median(RotationErrorOutliers(:,1)),
                                          mean(RotationErrorOutliers(:,1)), 
                                          norm(RotationErrorOutliers(:,1),1)
                                         ]'; 
                    BetaD_05(i,4:6)    = [median(RotationErrorOutliers(:,2)),
                                          mean(RotationErrorOutliers(:,2)), 
                                          norm(RotationErrorOutliers(:,2),1)
                                         ]'; 
                    BetaD_1(i,4:6)     = [median(RotationErrorOutliers(:,3)),
                                          mean(RotationErrorOutliers(:,3)), 
                                          norm(RotationErrorOutliers(:,3),1)
                                         ]'; 
                    BetaD_2(i,4:6)     = [median(RotationErrorOutliers(:,4)),
                                          mean(RotationErrorOutliers(:,4)), 
                                          norm(RotationErrorOutliers(:,4),1)
                                         ]'; 
                    BetaD_3(i,4:6)     = [median(RotationErrorOutliers(:,5)),
                                          mean(RotationErrorOutliers(:,5)), 
                                          norm(RotationErrorOutliers(:,5),1)
                                         ]';                                         
                                
                       
                                         
                     %Other Stuff
                     ICA_Alg_Index = 1; %FastICA G1
                     FastICA_G1(i,7) = norm(mean(abs(squeeze(Cntrsts_Norm_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:)))'),1); % 'Normilized Mean Abs Diff'
                     FastICA_G1(i,8) = norm(median(squeeze(Cntrsts_Norm_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1);%'Normilized Median Diff'
                     FastICA_G1(i,9) = norm(var(squeeze(Cntrsts_Norm_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1);% 'Normilized Var Diff';
                     FastICA_G1(i,10) = norm(mean(squeeze(Cntrsts_Absolute_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1);%'Absolute Mean Diff'
                     FastICA_G1(i,11) = norm(median(squeeze(Cntrsts_Absolute_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1); %'Absolute Median Diff'
                     FastICA_G1(i,12) = norm(mean(squeeze(Cntrsts_Absolute_MSE(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1); % 'Absolute MSE Mean'
                     
                     ICA_Alg_Index = 2; %FastICA G2
                     FastICA_G2(i,7) = norm(mean(abs(squeeze(Cntrsts_Norm_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:)))'),1); % 'Normilized Mean Abs Diff'
                     FastICA_G2(i,8) = norm(median(squeeze(Cntrsts_Norm_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1);%'Normilized Median Diff'
                     FastICA_G2(i,9) = norm(var(squeeze(Cntrsts_Norm_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1);% 'Normilized Var Diff';
                     FastICA_G2(i,10) = norm(mean(squeeze(Cntrsts_Absolute_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1);%'Absolute Mean Diff'
                     FastICA_G2(i,11) = norm(median(squeeze(Cntrsts_Absolute_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1); %'Absolute Median Diff'
                     FastICA_G2(i,12) = norm(mean(squeeze(Cntrsts_Absolute_MSE(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1); % 'Absolute MSE Mean'
                           
                     ICA_Alg_Index = 3; %FastICA G3
                     FastICA_G3(i,7) = norm(mean(abs(squeeze(Cntrsts_Norm_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:)))'),1); % 'Normilized Mean Abs Diff'
                     FastICA_G3(i,8) = norm(median(squeeze(Cntrsts_Norm_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1);%'Normilized Median Diff'
                     FastICA_G3(i,9) = norm(var(squeeze(Cntrsts_Norm_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1);% 'Normilized Var Diff';
                     FastICA_G3(i,10) = norm(mean(squeeze(Cntrsts_Absolute_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1);%'Absolute Mean Diff'
                     FastICA_G3(i,11) = norm(median(squeeze(Cntrsts_Absolute_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1); %'Absolute Median Diff'
                     FastICA_G3(i,12) = norm(mean(squeeze(Cntrsts_Absolute_MSE(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1); % 'Absolute MSE Mean'
                           
                     ICA_Alg_Index = 4; %FastICA G4
                     FastICA_G4(i,7) = norm(mean(abs(squeeze(Cntrsts_Norm_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:)))'),1); % 'Normilized Mean Abs Diff'
                     FastICA_G4(i,8) = norm(median(squeeze(Cntrsts_Norm_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1);%'Normilized Median Diff'
                     FastICA_G4(i,9) = norm(var(squeeze(Cntrsts_Norm_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1);% 'Normilized Var Diff';
                     FastICA_G4(i,10) = norm(mean(squeeze(Cntrsts_Absolute_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1);%'Absolute Mean Diff'
                     FastICA_G4(i,11) = norm(median(squeeze(Cntrsts_Absolute_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1); %'Absolute Median Diff'
                     FastICA_G4(i,12) = norm(mean(squeeze(Cntrsts_Absolute_MSE(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1); % 'Absolute MSE Mean'
                     
                     ICA_Alg_Index = 6; %Infomax
                     Ext_Infomax(i,7) = norm(mean(abs(squeeze(Cntrsts_Norm_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:)))'),1); % 'Normilized Mean Abs Diff'
                     Ext_Infomax(i,8) = norm(median(squeeze(Cntrsts_Norm_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1);%'Normilized Median Diff'
                     Ext_Infomax(i,9) = norm(var(squeeze(Cntrsts_Norm_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1);% 'Normilized Var Diff';
                     Ext_Infomax(i,10) = norm(mean(squeeze(Cntrsts_Absolute_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1);%'Absolute Mean Diff'
                     Ext_Infomax(i,11) = norm(median(squeeze(Cntrsts_Absolute_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1); %'Absolute Median Diff'
                     Ext_Infomax(i,12) = norm(mean(squeeze(Cntrsts_Absolute_MSE(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1); % 'Absolute MSE Mean'

                     ICA_Alg_Index = 8; %JADE
                     JADE(i,7) = norm(mean(abs(squeeze(Cntrsts_Norm_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:)))'),1); % 'Normilized Mean Abs Diff'
                     JADE(i,8) = norm(median(squeeze(Cntrsts_Norm_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1);%'Normilized Median Diff'
                     JADE(i,9) = norm(var(squeeze(Cntrsts_Norm_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1);% 'Normilized Var Diff';
                     JADE(i,10) = norm(mean(squeeze(Cntrsts_Absolute_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1);%'Absolute Mean Diff'
                     JADE(i,11) = norm(median(squeeze(Cntrsts_Absolute_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1); %'Absolute Median Diff'
                     JADE(i,12) = norm(mean(squeeze(Cntrsts_Absolute_MSE(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1); % 'Absolute MSE Mean'

                     ICA_Alg_Index = 10; %Radical
                     Radical(i,7) = norm(mean(abs(squeeze(Cntrsts_Norm_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:)))'),1); % 'Normilized Mean Abs Diff'
                     Radical(i,8) = norm(median(squeeze(Cntrsts_Norm_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1);%'Normilized Median Diff'
                     Radical(i,9) = norm(var(squeeze(Cntrsts_Norm_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1);% 'Normilized Var Diff';
                     Radical(i,10) = norm(mean(squeeze(Cntrsts_Absolute_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1);%'Absolute Mean Diff'
                     Radical(i,11) = norm(median(squeeze(Cntrsts_Absolute_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1); %'Absolute Median Diff'
                     Radical(i,12) = norm(mean(squeeze(Cntrsts_Absolute_MSE(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1); % 'Absolute MSE Mean'

                     ICA_Alg_Index = 12; %BetaD 0
                     BetaD_0(i,7) = norm(mean(abs(squeeze(Cntrsts_Norm_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:)))'),1); % 'Normilized Mean Abs Diff'
                     BetaD_0(i,8) = norm(median(squeeze(Cntrsts_Norm_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1);%'Normilized Median Diff'
                     BetaD_0(i,9) = norm(var(squeeze(Cntrsts_Norm_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1);% 'Normilized Var Diff';
                     BetaD_0(i,10) = norm(mean(squeeze(Cntrsts_Absolute_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1);%'Absolute Mean Diff'
                     BetaD_0(i,11) = norm(median(squeeze(Cntrsts_Absolute_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1); %'Absolute Median Diff'
                     BetaD_0(i,12) = norm(mean(squeeze(Cntrsts_Absolute_MSE(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1); % 'Absolute MSE Mean'

                     ICA_Alg_Index = 13; %BetaD 0.05
                     BetaD_05(i,7) = norm(mean(abs(squeeze(Cntrsts_Norm_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:)))'),1); % 'Normilized Mean Abs Diff'
                     BetaD_05(i,8) = norm(median(squeeze(Cntrsts_Norm_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1);%'Normilized Median Diff'
                     BetaD_05(i,9) = norm(var(squeeze(Cntrsts_Norm_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1);% 'Normilized Var Diff';
                     BetaD_05(i,10) = norm(mean(squeeze(Cntrsts_Absolute_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1);%'Absolute Mean Diff'
                     BetaD_05(i,11) = norm(median(squeeze(Cntrsts_Absolute_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1); %'Absolute Median Diff'
                     BetaD_05(i,12) = norm(mean(squeeze(Cntrsts_Absolute_MSE(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1); % 'Absolute MSE Mean'

                     ICA_Alg_Index = 14; %BetaD 0.1
                     BetaD_1(i,7) = norm(mean(abs(squeeze(Cntrsts_Norm_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:)))'),1); % 'Normilized Mean Abs Diff'
                     BetaD_1(i,8) = norm(median(squeeze(Cntrsts_Norm_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1);%'Normilized Median Diff'
                     BetaD_1(i,9) = norm(var(squeeze(Cntrsts_Norm_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1);% 'Normilized Var Diff';
                     BetaD_1(i,10) = norm(mean(squeeze(Cntrsts_Absolute_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1);%'Absolute Mean Diff'
                     BetaD_1(i,11) = norm(median(squeeze(Cntrsts_Absolute_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1); %'Absolute Median Diff'
                     BetaD_1(i,12) = norm(mean(squeeze(Cntrsts_Absolute_MSE(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1); % 'Absolute MSE Mean'

                     ICA_Alg_Index = 15; %BetaD 0.2
                     BetaD_2(i,7) = norm(mean(abs(squeeze(Cntrsts_Norm_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:)))'),1); % 'Normilized Mean Abs Diff'
                     BetaD_2(i,8) = norm(median(squeeze(Cntrsts_Norm_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1);%'Normilized Median Diff'
                     BetaD_2(i,9) = norm(var(squeeze(Cntrsts_Norm_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1);% 'Normilized Var Diff';
                     BetaD_2(i,10) = norm(mean(squeeze(Cntrsts_Absolute_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1);%'Absolute Mean Diff'
                     BetaD_2(i,11) = norm(median(squeeze(Cntrsts_Absolute_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1); %'Absolute Median Diff'
                     BetaD_2(i,12) = norm(mean(squeeze(Cntrsts_Absolute_MSE(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1); % 'Absolute MSE Mean'

                     ICA_Alg_Index = 16; %BetaD 0.3
                     BetaD_3(i,7) = norm(mean(abs(squeeze(Cntrsts_Norm_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:)))'),1); % 'Normilized Mean Abs Diff'
                     BetaD_3(i,8) = norm(median(squeeze(Cntrsts_Norm_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1);%'Normilized Median Diff'
                     BetaD_3(i,9) = norm(var(squeeze(Cntrsts_Norm_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1);% 'Normilized Var Diff';
                     BetaD_3(i,10) = norm(mean(squeeze(Cntrsts_Absolute_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1);%'Absolute Mean Diff'
                     BetaD_3(i,11) = norm(median(squeeze(Cntrsts_Absolute_Diff(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1); %'Absolute Median Diff'
                     BetaD_3(i,12) = norm(mean(squeeze(Cntrsts_Absolute_MSE(:,NumSamplesIndex,RotationIndex,NumOutliersIndex,Source1OutlierIndex,Source2OutlierIndex,ICA_Alg_Index,:))'),1); % 'Absolute MSE Mean'
                               
                end %else if
    
            end %for Source1OutlierIndex = 1:5, %0,1,3,5,7
            
        end % for NumOutliersIndex = 1:5  %0,1,3,5,7
   
    end% for RotationIndex = 1:2, %0, 45
    
end %NumSamplesIndex = 1:2, %100,200



%New plots

%A plot of the Median Amari Sep performance for each algorithm as the outlier moves from none, to 0,1,3,5 and 7 for each algorithm.
%On preliminary results, the initial mixing rotation angle, had no significant impact on the Amari separation performance. (1 picture)
%Sample size? Leave it out for now.

%[1:6], Sample Size =  100, Rot = 0; [7:12], Sample Size = 100, Rot = 45; [13:18], Sample Size  = 200, Rot = 0; [19:24] Sample Size = 200, Rot = 45;
SSize = 100;
Rot = 0;
rows = [1:6];
%
%         Amari                    Angle Err       1-Norm of Normlized Cntrst   1-Norm of Absolute Cntrst
% Median   Mean   Var   Median   Mean   1-Norm    Median   Mean   Var       Median   Mean   Var   
%  1        2      3     4        5      6         7        8      9         10       11     12
col = 1;

figure;
subplot(1,2,1),plot(FastICA_G1(rows,col),'.-','markerfacecolor','b');
hold on;
subplot(1,2,1),plot(FastICA_G2(rows,col),'o-','markerfacecolor','b');
subplot(1,2,1),plot(FastICA_G3(rows,col),'x-','markerfacecolor','b');
subplot(1,2,1),plot(FastICA_G4(rows,col),'+-','markerfacecolor','b');
subplot(1,2,1),plot(Ext_Infomax(rows,col),'*-','markerfacecolor','b');
subplot(1,2,1),plot(JADE(rows,col),'s-','markerfacecolor','b');
subplot(1,2,1),plot(Radical(rows,col),'p-','markerfacecolor','b');
subplot(1,2,1),plot(BetaD_0(rows,col),'d-','markerfacecolor','b');
subplot(1,2,1),plot(BetaD_05(rows,col),'^-','markerfacecolor','b');
subplot(1,2,1),plot(BetaD_1(rows,col),'<-','markerfacecolor','b');
subplot(1,2,1),plot(BetaD_2(rows,col),'>-','markerfacecolor','b');
subplot(1,2,1),plot(BetaD_3(rows,col),'v-','markerfacecolor','b');
set(gca, 'XTickLabel',{'None','0','1','3','5','7'});
ylabel('Normalized API');
xlabel('Outlier location [\sigma]');
%legend('FastICA G1','FastICA G2','FastICA G3','FastICA G4','Ext-Infomax','JADE','Radical','BetaD 0.0','BetaD 0.05','BetaD 0.1','BetaD 0.2','BetaD 0.3',2);


%Same plot as Median Amari Sep performance, but without JADE, Infomax, FastICA G3 and G4 and BetaD 0

subplot(1,2,2),plot(FastICA_G1(rows,col),'.-','markerfacecolor','b');
hold on;
subplot(1,2,2),plot(FastICA_G2(rows,col),'o-','markerfacecolor','b');
subplot(1,2,2),plot(Ext_Infomax(rows,col),'*-','markerfacecolor','b');
subplot(1,2,2),plot(Radical(rows,col),'p-','markerfacecolor','b');
subplot(1,2,2),plot(BetaD_0(rows,col),'d-','markerfacecolor','b');
subplot(1,2,2),plot(BetaD_05(rows,col),'^-','markerfacecolor','b');
subplot(1,2,2),plot(BetaD_1(rows,col),'<-','markerfacecolor','b');
subplot(1,2,2),plot(BetaD_2(rows,col),'>-','markerfacecolor','b');
subplot(1,2,2),plot(BetaD_3(rows,col),'v-','markerfacecolor','b');
set(gca, 'XTickLabel',{'None','0','1','3','5','7'});
ylabel('Normalized API');
xlabel('Outlier location [\sigma]');
%legend('FastICA G1','FastICA G2','Infomax','Radical','BetaD 0.0','BetaD 0.05','BetaD 0.1','BetaD 0.2','BetaD 0.3',2);


%mkdir('e:\Thesis\Results\',date);
%mkdir(['e:\Thesis\Results\',date],'Experiment5b');
%Save Image
maximize; %Obtained maximize.m file from Matlab central
Experiment_name = ['e:\Thesis\Results\',date,'\Exp2\Median_API_SampleSize_',num2str(SSize),'_Rot',num2str(Rot)];
saveas(gcf,Experiment_name,'fig');
opts = struct('bounds','tight','Renderer','painters','linestylemap',[],'width',4.0,'fontmode','fixed', 'BoundsCode','mcode','fontsize',10,'LineWidth',1,'format','eps','Color','bw','Resolution',300); %Width is 6inches
setpref('exportfig','defaults',opts);
exportfig(gcf,Experiment_name); 

opts = struct('bounds','tight','Renderer','painters','linestylemap',[],'width',4.0,'fontmode','fixed', 'BoundsCode','mcode','fontsize',10,'LineWidth',1,'format','png','Color','bw','Resolution',300); %Width is 6inches
setpref('exportfig','defaults',opts);
exportfig(gcf,Experiment_name);






%A plot of the 1-norm of the Angle Error for each algorithm as the outlier moves from none, to 0,1,3,5 and 7 for each algorithm.
%Sample size? Leave it out for now.

col = 6;
figure;
subplot(1,2,1),plot(FastICA_G1(rows,col),'.-','markerfacecolor','b');
hold on;
subplot(1,2,1),plot(FastICA_G2(rows,col),'o-','markerfacecolor','b');
subplot(1,2,1),plot(FastICA_G3(rows,col),'x-','markerfacecolor','b');
subplot(1,2,1),plot(FastICA_G4(rows,col),'+-','markerfacecolor','b');
subplot(1,2,1),plot(Ext_Infomax(rows,col),'*-','markerfacecolor','b');
subplot(1,2,1),plot(JADE(rows,col),'s-','markerfacecolor','b');
subplot(1,2,1),plot(Radical(rows,col),'p-','markerfacecolor','b');
subplot(1,2,1),plot(BetaD_0(rows,col),'d-','markerfacecolor','b');
subplot(1,2,1),plot(BetaD_05(rows,col),'^-','markerfacecolor','b');
subplot(1,2,1),plot(BetaD_1(rows,col),'<-','markerfacecolor','b');
subplot(1,2,1),plot(BetaD_2(rows,col),'>-','markerfacecolor','b');
subplot(1,2,1),plot(BetaD_3(rows,col),'v-','markerfacecolor','b');
set(gca, 'XTickLabel',{'None','0','1','3','5','7'});
ylabel('First-norm Angle Error');
xlabel('Outlier location [\sigma]');
%legend('FastICA G1','FastICA G2','FastICA G3','FastICA G4','Ext-Infomax','JADE','Radical','BetaD 0.0','BetaD 0.05','BetaD 0.1','BetaD 0.2','BetaD 0.3',2);


%A plot of the 1-norm of the Normalized Contrast Error for each algorithm as the outlier moves from none, to 0,1,3,5 and 7 for each algorithm.
%Sample size? Leave it out for now.

col = 7;
%figure;
subplot(1,2,2),plot(FastICA_G1(rows,col),'.-','markerfacecolor','b');
hold on;
subplot(1,2,2),plot(FastICA_G2(rows,col),'o-','markerfacecolor','b');
subplot(1,2,2),plot(FastICA_G3(rows,col),'x-','markerfacecolor','b');
subplot(1,2,2),plot(FastICA_G4(rows,col),'+-','markerfacecolor','b');
subplot(1,2,2),plot(Ext_Infomax(rows,col),'*-','markerfacecolor','b');
subplot(1,2,2),plot(JADE(rows,col),'s-','markerfacecolor','b');
subplot(1,2,2),plot(Radical(rows,col),'p-','markerfacecolor','b');
subplot(1,2,2),plot(BetaD_0(rows,col),'d-','markerfacecolor','b');
subplot(1,2,2),plot(BetaD_05(rows,col),'^-','markerfacecolor','b');
subplot(1,2,2),plot(BetaD_1(rows,col),'<-','markerfacecolor','b');
subplot(1,2,2),plot(BetaD_2(rows,col),'>-','markerfacecolor','b');
subplot(1,2,2),plot(BetaD_3(rows,col),'v-','markerfacecolor','b');
set(gca, 'XTickLabel',{'None','0','1','3','5','7'});
ylabel('First-norm Contrast Error');
xlabel('Outlier location [\sigma]');
%legend('FastICA G1','FastICA G2','FastICA G3','FastICA G4','Ext-Infomax','JADE','Radical','BetaD 0.0','BetaD 0.05','BetaD 0.1','BetaD 0.2','BetaD 0.3',2);

%Save Image
maximize; %Obtained maximize.m file from Matlab central
Experiment_name = ['e:\Thesis\Results\',date,'\Exp2\1-norm_NormalizedContrastErrorAngleError_SampleSize_',num2str(SSize),'_Rot',num2str(Rot)];
saveas(gcf,Experiment_name,'fig');
opts = struct('bounds','tight','Renderer','painters','linestylemap',[],'width',4.0,'fontmode','fixed', 'BoundsCode','mcode','fontsize',10,'LineWidth',1,'format','eps','Color','bw','Resolution',300); %Width is 6inches
setpref('exportfig','defaults',opts);
exportfig(gcf,Experiment_name); 

opts = struct('bounds','tight','Renderer','painters','linestylemap',[],'width',4.0,'fontmode','fixed', 'BoundsCode','mcode','fontsize',10,'LineWidth',1,'format','png','Color','bw','Resolution',300); %Width is 6inches
setpref('exportfig','defaults',opts);
exportfig(gcf,Experiment_name);
