%This file calculates the Extended-Infomax objective function landscape.
%Neil Gadhok, v1.0, Dec 4, 2004.
function [L] = Infomax_Cntrst(x,W)



%The Infomax princple is to based on maximizing the output entropy, or
%information flow, of a neural network with nonlinear outputs. Infomation
% transmission requires that we maximize the mutual information between
%the inputs x and output y. This is only meaningful if there is an
%info loss in the network. Maximization of the mutual information, is 
%equivalent to maximizing the output entropy.
%[LeGS99] T. Lee, M. Girolami and T. Sejnowski, "Independent Component
%Analysis using an extended infomax algorithm for mixed subgaussian
%and supergaussian sources," Neural Computation, vol. 11, pp. 417-441,
%1999.

[m,n] = size(x);
        
L = 0;
u = W*x;
p = zeros(m,n);
        
        %whiten? u should be zero mean and have unit variance
%          u = u - mean(u,2)*ones(1,length(u)); %Make u zero mean
%          [E, D] = eig (cov(u', 1)); %The 1 normalizes by N.
%          whiteningMatrix_u = inv (sqrt (D)) * E';
%          u = whiteningMatrix_u*u;
        
        
        %Eq 2.7 [LeGS99]
        %L(u,W) = log |det W| + sum(i=1:m) log (p_i(u_i)).
        %We want to maximize the likelihood, to obtain ....
            
        %We must solve the Likelihood for each row of observations
        for i = 1:m,
            if kurtosis(u(i,:),0) < 0, %Then subgaussian  %MUST CHANGE TO  Eq. 2.28 in [LeGS99]
            
                %Eqn. 2.12, [LeGS99]
                %p(u) = 0.5*(N(mu,sigma^2) + N(-mu,sigma^2)), where N is a normal density with mean 
                %mu and variance sigma^2.
                 p(i,:) = 0.5*( normpdf(u(i,:),1,1) + normpdf(u(i,:),-1,1));
            else %Then supergaussian
                
                %Eqn 2.18 {LeGS99]
                %p(u) = p_G(u)sech^2(u), where p_G(u) = N(0,1)
                p(i,:) = normpdf(u(i,:),0,1).*(sech(u(i,:)).^2);
              
            end
                                    
        end
        
        %Eqn 2.7
        L = (1/n)*sum(sum(log(p)));
        L = -(log(abs(det(W))) + L); %Beacuse we want to minimize. 

